@@ -7,6 +7,7 @@
  * Authors: Víctor M. Jáquez L. <vjaquez@igalia.com>
  *          Juan A. Suarez Romero <jasuarez@igalia.com>
  *          Jens Georg <jensg@openismus.com>
+ *          Mathias Hasselmann <mathias@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -44,8 +45,8 @@
 #include <grilo.h>
 #include "grl-net-wc.h"
 #include "grl-net-private.h"
+#include "grl-net-mock-private.h"
 
-#define GRL_LOG_DOMAIN_DEFAULT wc_log_domain
 GRL_LOG_DOMAIN(wc_log_domain);
 
 enum {
@@ -190,6 +191,7 @@ grl_net_wc_init (GrlNetWc *wc)
   wc->priv->pending = g_queue_new ();
 
   set_thread_context (wc);
+  init_mock_requester (wc);
   init_requester (wc);
 }
 
@@ -203,6 +205,7 @@ grl_net_wc_finalize (GObject *object)
 
   cache_down (wc);
   finalize_requester (wc);
+  finalize_mock_requester (wc);
 
   g_queue_free (wc->priv->pending);
   g_object_unref (wc->priv->session);
@@ -283,8 +286,20 @@ struct request_clos {
   guint source_id;
 };
 
+static void
+request_clos_destroy (gpointer data)
+{
+  struct request_clos *c = (struct request_clos *) data;
+
+  g_free (c->url);
+  if (c->headers) {
+    g_hash_table_unref (c->headers);
+  }
+  g_free (c);
+}
+
 static gboolean
-get_url_delayed (gpointer user_data)
+get_url_cb (gpointer user_data)
 {
   struct request_clos *c = (struct request_clos *) user_data;
 
@@ -295,13 +310,10 @@ get_url_delayed (gpointer user_data)
     g_assert (c == d);
   }
 
-  get_url_now (c->self, c->url, c->headers, c->result, c->cancellable);
-
-  g_free (c->url);
-  if (c->headers) {
-    g_hash_table_unref (c->headers);
-  }
-  g_free (c);
+  if (is_mocked ())
+    get_url_mocked (c->self, c->url, c->headers, c->result, c->cancellable);
+  else
+    get_url_now (c->self, c->url, c->headers, c->result, c->cancellable);
 
   return FALSE;
 }
@@ -318,17 +330,6 @@ get_url (GrlNetWc *self,
   struct request_clos *c;
   GrlNetWcPrivate *priv = self->priv;
 
-  g_get_current_time (&now);
-
-  if ((now.tv_sec - priv->last_request.tv_sec) > priv->throttling) {
-    get_url_now (self, url, headers, result, cancellable);
-    g_get_current_time (&priv->last_request);
-
-    return;
-  }
-
-  GRL_DEBUG ("delaying web request");
-
   /* closure */
   c = g_new (struct request_clos, 1);
   c->self = self;
@@ -337,11 +338,22 @@ get_url (GrlNetWc *self,
   c->result = result;
   c->cancellable = cancellable;
 
-  priv->last_request.tv_sec += priv->throttling;
-  id = g_timeout_add_seconds (priv->last_request.tv_sec - now.tv_sec,
-                              get_url_delayed, c);
-  c->source_id = id;
+  g_get_current_time (&now);
 
+  if ((now.tv_sec - priv->last_request.tv_sec) > priv->throttling
+          || is_mocked()) {
+    id = g_idle_add_full (G_PRIORITY_HIGH_IDLE,
+                          get_url_cb, c, request_clos_destroy);
+  } else {
+    GRL_DEBUG ("delaying web request");
+
+    priv->last_request.tv_sec += priv->throttling;
+    id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT,
+                                     priv->last_request.tv_sec - now.tv_sec,
+                                     get_url_cb, c, request_clos_destroy);
+  }
+
+  c->source_id = id;
   g_queue_push_head (self->priv->pending, c);
 }
 
@@ -477,6 +489,7 @@ grl_net_wc_request_with_headers_hash_async (GrlNetWc *self,
   get_url (self, uri, headers, G_ASYNC_RESULT (result), cancellable);
 }
 
+
 /**
  * grl_net_wc_request_finish:
  * @self: a #GrlNetWc instance
@@ -515,10 +528,16 @@ grl_net_wc_request_finish (GrlNetWc *self,
     goto end_func;
   }
 
-  get_content(self, op, content, length);
+  if (is_mocked ())
+    get_content_mocked (self, op, content, length);
+  else
+    get_content(self, op, content, length);
 
 end_func:
-  free_op_res (op);
+  if (is_mocked ())
+    free_mock_op_res (op);
+  else
+    free_op_res (op);
 
   return ret;
 }
