@@ -67,6 +67,8 @@ G_BEGIN_DECLS
  * @GRL_MEDIA_SERIALIZE_FULL: Full mode
  *
  * GrlMedia serialize type
+ *
+ * Since: 0.2.3
  */
 typedef enum {
   GRL_MEDIA_SERIALIZE_BASIC,
@@ -74,6 +76,23 @@ typedef enum {
   GRL_MEDIA_SERIALIZE_FULL
 } GrlMediaSerializeType;
 
+
+/**
+ * GrlMediaType:
+ * @GRL_MEDIA_TYPE_NONE: no media
+ * @GRL_MEDIA_TYPE_AUDIO: audio media
+ * @GRL_MEDIA_TYPE_VIDEO: video media
+ * @GRL_MEDIA_TYPE_IMAGE: image media
+ * @GRL_MEDIA_TYPE_ALL: any media
+ */
+typedef enum {
+  GRL_MEDIA_TYPE_NONE  = 0,
+  GRL_MEDIA_TYPE_AUDIO = (1 << 0),
+  GRL_MEDIA_TYPE_VIDEO = (1 << 1),
+  GRL_MEDIA_TYPE_IMAGE = (1 << 2),
+  GRL_MEDIA_TYPE_ALL   = (GRL_MEDIA_TYPE_AUDIO | GRL_MEDIA_TYPE_VIDEO | GRL_MEDIA_TYPE_IMAGE)
+} GrlMediaType;
+
 typedef struct _GrlMedia      GrlMedia;
 typedef struct _GrlMediaClass GrlMediaClass;
 
@@ -121,6 +140,19 @@ void grl_media_set_duration (GrlMedia *media, gint duration);
 
 void grl_media_set_publication_date (GrlMedia *media, const GDateTime *date);
 
+void grl_media_set_region (GrlMedia *media,
+                           const gchar *region);
+
+void grl_media_set_region_data (GrlMedia *media,
+                                const gchar *region,
+                                const GDateTime *publication_date,
+                                const gchar *certificate);
+
+void grl_media_add_region_data (GrlMedia *media,
+                                const gchar *region,
+                                const GDateTime *publication_date,
+                                const gchar *certificate);
+
 void grl_media_set_creation_date (GrlMedia *media,
                                   const GDateTime *creation_date);
 
@@ -149,6 +181,10 @@ void grl_media_set_rating (GrlMedia *media, gfloat rating, gfloat max);
 
 void grl_media_set_url_data (GrlMedia *media, const gchar *url, const gchar *mime);
 
+void grl_media_set_favourite (GrlMedia *media, gboolean favourite);
+
+void grl_media_set_keyword (GrlMedia *media, const gchar *keyword);
+
 void grl_media_add_url_data (GrlMedia *media, const gchar *url, const gchar *mime);
 
 void grl_media_add_author (GrlMedia *media, const gchar *author);
@@ -161,6 +197,8 @@ void grl_media_add_external_player (GrlMedia *media, const gchar *player);
 
 void grl_media_add_external_url (GrlMedia *media, const gchar *url);
 
+void grl_media_add_keyword (GrlMedia *media, const gchar *keyword);
+
 const gchar *grl_media_get_id (GrlMedia *media);
 
 const gchar *grl_media_get_url (GrlMedia *media);
@@ -193,6 +231,17 @@ gint grl_media_get_duration (GrlMedia *media);
 
 GDateTime *grl_media_get_publication_date (GrlMedia *media);
 
+const gchar *grl_media_get_region (GrlMedia *media);
+
+const gchar *grl_media_get_region_data(GrlMedia *media,
+                                       const GDateTime **publication_date,
+                                       const gchar **certificate);
+
+const gchar *grl_media_get_region_data_nth(GrlMedia *media,
+                                           guint index,
+                                           const GDateTime **publication_date,
+                                           const gchar **certificate);
+
 GDateTime *grl_media_get_creation_date (GrlMedia *media);
 
 GDateTime *grl_media_get_modification_date (GrlMedia *media);
@@ -223,6 +272,12 @@ const gchar *grl_media_get_license (GrlMedia *media);
 
 gfloat grl_media_get_start_time (GrlMedia *media);
 
+gboolean grl_media_get_favourite (GrlMedia *media);
+
+const gchar *grl_media_get_keyword (GrlMedia *media);
+
+const gchar * grl_media_get_keyword_nth (GrlMedia *media, guint index);
+
 GType grl_media_get_type (void) G_GNUC_CONST;
 
 GrlMedia *grl_media_new (void);
