@@ -25,12 +25,14 @@
 
 #include <config.h>
 
+#ifdef HAVE_OAUTH
+#include "flickr-oauth.h"
+#endif
+
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <string.h>
 
-#include "flickr-auth.h"
-
 #define GRL_LOG_DOMAIN_DEFAULT  test_ui_log_domain
 GRL_LOG_DOMAIN_STATIC(test_ui_log_domain);
 
@@ -187,7 +189,9 @@ static const gchar *ui_definition =
 "<ui>"
 " <menubar name='MainMenu'>"
 "  <menu name='FileMenu' action='FileMenuAction' >"
+#ifdef HAVE_OAUTH
 "   <menuitem name='Authorize Flickr' action='AuthorizeFlickrAction' />"
+#endif
 "   <menuitem name='Shutdown plugins' action='ShutdownPluginsAction' />"
 "   <menuitem name='Load all plugins' action='LoadAllPluginsAction' />"
 "   <menuitem name='Changes notification' action='ChangesNotificationAction' />"
@@ -202,11 +206,13 @@ static GrlOperationOptions *default_resolve_options = NULL;
 static void show_browsable_sources (void);
 static void quit_cb (GtkAction *action);
 
+#ifdef HAVE_OAUTH
 static gchar *authorize_flickr (void);
 static void authorize_flickr_cb (GtkAction *action);
+#endif
 
 static void shutdown_plugins_cb (GtkAction *action);
-static void shutdown_plugins (void);
+static void shutdown_plugins (gboolean ui_active);
 
 static void load_all_plugins_cb (GtkAction *action);
 static void load_all_plugins (void);
@@ -220,8 +226,10 @@ static void content_changed_cb (GrlSource *source,
 
 static GtkActionEntry entries[] = {
   { "FileMenuAction", NULL, "_File" },
+#ifdef HAVE_OAUTH
   { "AuthorizeFlickrAction", GTK_STOCK_CONNECT, "_Authorize Flickr", NULL,
     "AuthorizeFlickr", G_CALLBACK (authorize_flickr_cb) },
+#endif
   { "ShutdownPluginsAction", GTK_STOCK_REFRESH, "_Shutdown Plugins", NULL,
     "ShutdownPlugins", G_CALLBACK (shutdown_plugins_cb) },
   { "LoadAllPluginsAction", GTK_STOCK_REFRESH, "_Load All Plugins", NULL,
@@ -241,16 +249,18 @@ quit_cb (GtkAction *action)
   gtk_main_quit ();
 }
 
+#ifdef HAVE_OAUTH
 static void
 authorize_flickr_cb (GtkAction *action)
 {
   authorize_flickr ();
 }
+#endif
 
 static void
 shutdown_plugins_cb (GtkAction *action)
 {
-  shutdown_plugins ();
+  shutdown_plugins (TRUE);
 }
 
 static void
@@ -1394,7 +1404,7 @@ get_config_dir (void)
 }
 
 static gchar *
-load_flickr_token (void)
+load_flickr_token (gchar **secret)
 {
   GKeyFile *keyfile;
   gchar *path;
@@ -1415,6 +1425,7 @@ load_flickr_token (void)
     goto bailout;
 
   token = g_key_file_get_value (keyfile, "flickr", "auth-token", NULL);
+  (*secret) = g_key_file_get_value (keyfile, "flickr", "auth-token-secret", NULL);
 
 bailout:
   g_free (file);
@@ -1423,7 +1434,7 @@ bailout:
 }
 
 static void
-save_flickr_token (const gchar *token)
+save_flickr_token (const gchar *token, const gchar *secret)
 {
   GKeyFile *keyfile;
   gchar *path;
@@ -1441,6 +1452,7 @@ save_flickr_token (const gchar *token)
   keyfile = g_key_file_new ();
   g_key_file_load_from_file (keyfile, file, G_KEY_FILE_NONE, NULL);
   g_key_file_set_value (keyfile, "flickr", "auth-token", token);
+  g_key_file_set_value (keyfile, "flickr", "auth-token-secret", secret);
 
   {
     GError *error = NULL;
@@ -1457,6 +1469,7 @@ save_flickr_token (const gchar *token)
   g_key_file_free (keyfile);
 }
 
+#ifdef HAVE_OAUTH
 static void
 activate_ok_button (GtkLabel *label,
                     gchar *uri,
@@ -1469,6 +1482,7 @@ activate_ok_button (GtkLabel *label,
                 NULL);
   gtk_widget_set_sensitive (user_data, TRUE);
 }
+#endif /* HAVE_OAUTH */
 
 static void
 load_file_config (void)
@@ -1487,6 +1501,7 @@ load_file_config (void)
   g_free (config_file);
 }
 
+#ifdef HAVE_OAUTH
 static gchar *
 authorize_flickr (void)
 {
@@ -1494,18 +1509,24 @@ authorize_flickr (void)
   GtkWidget *fail_dialog;
   GtkWidget *label;
   GtkWidget *view;
-  gchar *markup;
+  GtkWidget *input;
+  const gchar *verifier;
+  gchar *markup = NULL;
   gchar *token = NULL;
-  gchar *login_link;
+  gchar *login_link = NULL;
   GtkWidget *ok_button;
 
-  gchar *frob = flickr_get_frob (FLICKR_KEY, FLICKR_SECRET);
-  if (!frob) {
-    GRL_WARNING ("Unable to obtain a Flickr's frob");
+  gchar *rt_secret = NULL;
+  gchar *at_secret = NULL;
+
+  gchar *rt = flickroauth_get_request_token (FLICKR_KEY, FLICKR_SECRET, &rt_secret);
+  if (!rt) {
+    GRL_WARNING ("Unable to obtain a Flickr's Request Key");
     return NULL;
   }
 
-  login_link = flickr_get_login_link (FLICKR_KEY, FLICKR_SECRET, frob, "read");
+  login_link = flickroauth_authorization_url (rt, "read");
+
   view = gtk_text_view_new ();
   gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)),
                             FLICKR_AUTHORIZE_MSG,
@@ -1522,6 +1543,8 @@ authorize_flickr (void)
   gtk_label_set_markup (GTK_LABEL (label), markup);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 
+  input = gtk_entry_new ();
+
   dialog =
     gtk_dialog_new_with_buttons ("Authorize Flickr access",
                                  GTK_WINDOW (gtk_widget_get_parent_window (view)),
@@ -1530,6 +1553,7 @@ authorize_flickr (void)
 
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), view, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), label, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), input, TRUE, TRUE, 0);
 
   ok_button = gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_OK, GTK_RESPONSE_OK);
   gtk_widget_set_sensitive (ok_button, FALSE);
@@ -1542,9 +1566,10 @@ authorize_flickr (void)
 
   gtk_widget_show_all (dialog);
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
-    token = flickr_get_token (FLICKR_KEY, FLICKR_SECRET, frob);
+    verifier = gtk_entry_get_text (GTK_ENTRY (input));
+    token = flickroauth_get_access_token (FLICKR_KEY, FLICKR_SECRET, rt, rt_secret, verifier, &at_secret);
     if (token) {
-      save_flickr_token (token);
+      save_flickr_token (token, at_secret);
     } else {
       fail_dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_parent_window (view)),
                                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -1557,12 +1582,16 @@ authorize_flickr (void)
   }
 
   gtk_widget_destroy (dialog);
-  g_free (frob);
+  g_free (rt);
+  g_free (rt_secret);
+  g_free (at_secret);
+
   g_free (login_link);
   g_free (markup);
 
   return token;
 }
+#endif /* HAVE_OAUTH */
 
 static void
 set_flickr_config (void)
@@ -1570,6 +1599,7 @@ set_flickr_config (void)
   GrlConfig *config;
   GrlRegistry *registry;
   gchar *token;
+  gchar *secret = NULL;
 
   registry = grl_registry_get_default ();
 
@@ -1578,24 +1608,30 @@ set_flickr_config (void)
   grl_config_set_api_secret (config, FLICKR_SECRET);
   grl_registry_add_config (registry, config, NULL);
 
-  token = load_flickr_token ();
+  token = load_flickr_token (&secret);
 
+#ifdef HAVE_OAUTH
   if (!token) {
     token = authorize_flickr ();
     if (!token) {
       /* Save empty token to avoid asking again */
-      save_flickr_token ("");
+      save_flickr_token ("", "");
     }
   }
+#else
+  save_flickr_token("", "");
+#endif
 
   if (token && token[0] != '\0') {
     config = grl_config_new ("grl-flickr", NULL);
     grl_config_set_api_key (config, FLICKR_KEY);
     grl_config_set_api_secret (config, FLICKR_SECRET);
     grl_config_set_api_token (config, token);
+    grl_config_set_api_token_secret (config, secret);
     grl_registry_add_config (registry, config, NULL);
   }
   g_free (token);
+  g_free (secret);
 }
 
 static void
@@ -1651,6 +1687,23 @@ set_local_config (void)
   grl_registry_add_config (registry, config, NULL);
 }
 
+static void
+set_filesystem_config (void)
+{
+  GrlConfig *config1, *config2;
+  GrlRegistry *registry;
+
+  config1 = grl_config_new ("grl-filesystem", NULL);
+  grl_config_set_string (config1, "base-uri", "recent:///");
+
+  config2 = grl_config_new ("grl-filesystem", NULL);
+  grl_config_set_string (config2, "base-uri", "file:///");
+
+  registry = grl_registry_get_default ();
+  grl_registry_add_config (registry, config1, NULL);
+  grl_registry_add_config (registry, config2, NULL);
+}
+
 static void
 launchers_setup (void)
 {
@@ -2139,7 +2192,7 @@ load_plugins (void)
 }
 
 static void
-shutdown_plugins (void)
+shutdown_plugins (gboolean ui_active)
 {
   GList *plugins;
   GList *plugin_iter;
@@ -2150,7 +2203,8 @@ shutdown_plugins (void)
 
   /* Let's make sure we don't have references to stuff
      we are about to shut down */
-  clear_ui ();
+  if (ui_active)
+    clear_ui ();
 
   registry = grl_registry_get_default ();
 
@@ -2174,9 +2228,11 @@ shutdown_plugins (void)
 				     NULL);
 
   /* Reload UI */
-  reset_ui ();
-  search_combo_setup ();
-  query_combo_setup ();
+  if (ui_active) {
+    reset_ui ();
+    search_combo_setup ();
+    query_combo_setup ();
+  }
 }
 
 static void
@@ -2198,6 +2254,7 @@ configure_plugins (void)
   set_vimeo_config ();
   set_tmdb_config ();
   set_local_config ();
+  set_filesystem_config ();
 }
 
 int
@@ -2212,5 +2269,6 @@ main (int argc, gchar *argv[])
   configure_plugins ();
   load_plugins ();
   gtk_main ();
+  shutdown_plugins (FALSE);
   return 0;
 }
